@@ -25,7 +25,7 @@ pub fn tmpl_fn_wrapper(body: String) -> String {
 pub fn tmpl_args_fewer_than(args_count: usize) -> String {
   format!(
     "
-if (arguments.length < {}) {{ throw new Error('Too few arguments') }}",
+if (arguments.length < {}) throw new Error('too few arguments')",
     args_count
   )
 }
@@ -33,8 +33,8 @@ if (arguments.length < {}) {{ throw new Error('Too few arguments') }}",
 pub fn tmpl_args_between(a: usize, b: usize) -> String {
   format!(
     "
-if (arguments.length < {}) {{ throw new Error('Too few arguments') }}
-if (arguments.length > {}) {{ throw new Error('Too many arguments') }}",
+if (arguments.length < {}) throw new Error('too few arguments');
+if (arguments.length > {}) throw new Error('too many arguments');",
     a, b
   )
 }
@@ -42,7 +42,7 @@ if (arguments.length > {}) {{ throw new Error('Too many arguments') }}",
 pub fn tmpl_args_exact(args_count: usize) -> String {
   format!(
     "
-if (arguments.length !== {}) {{ throw new Error('Args length mismatch') }}",
+if (arguments.length !== {}) throw new Error('argument sizes do not match');",
     args_count
   )
 }
@@ -69,9 +69,7 @@ pub fn tmpl_tail_recursion(
   let {ret_var} = null;
   let {times_var} = 0;
   while(true) {{ /* Tail Recursion */
-    if ({times_var} > 10000) {{
-      throw new Error('Expected tail recursion to exist quickly')
-    }}
+    if ({times_var} > 10000) throw new Error('tail recursion not stopping');
     {body}
     if ({ret_var} instanceof {var_prefix}CalcitRecur) {{
       {check_recur_args}
@@ -80,7 +78,7 @@ pub fn tmpl_tail_recursion(
       {times_var} += 1;
       continue;
     }} else {{
-      return {ret_var}
+      return {ret_var};
     }}
   }}
 }}
